==> datak-vue-components-0.1.0.tgz: package/src/api.ts <==
export const config = { base: "localhost:8000", protocol: "http" };


type ApiRequest = {
  method: string;
  path: string;
  data?: unknown;
};

type ApiHeaders = Record<string, string>;

type ApiOpts = {
  method: string;
  headers: ApiHeaders;
  body?: unknown;
  credentials: string;
};

export class APIError extends Error {
  public apiErrors: any;
  constructor(object: unknown) {
    super("APIError");
    this.apiErrors = object;
  }
  toString() {
    JSON.stringify(this.apiErrors);
  }
}

async function send({ method, path, data }: ApiRequest): Promise<any> {
  const { base, protocol } = config;
  const fetch = window.fetch;
  const opts: ApiOpts = {
    method,
    headers: {
      "Content-Type": "application/json",
    },
    credentials: "include",
  };

  // if (path !== "rest-auth/login/") {
  //   opts.credentials = "include";
  // }

  opts.body = JSON.stringify(data);

  const url = `${protocol}://${base}/${path}`;
  console.log(opts, url);
  const r = await fetch(url, opts as RequestInit);

  if (!r.ok) {
    const errors = await r.json();
    throw new APIError(errors);
  } else {
    if (method === "DELETE") {
      console.log(r);
      console.log("text", await r.text());
      return true;
    } else {
      return await r.json();
    }
  }
}

export function get(path: string): Promise<any> {
  return send({ method: "GET", path });
}

export function del(path: string): Promise<any> {
  return send({ method: "DELETE", path });
}

export function post(path: string, data: unknown): Promise<any> {
  return send({ method: "POST", path, data });
}

export function put(path: string, data: unknown): Promise<any> {
  return send({ method: "PUT", path, data });
}

export function patch(path: string, data: unknown): Promise<any> {
  return send({ method: "PATCH", path, data });
}

==> datak-vue-components-0.2.0.tgz: package/src/api.ts <==
export const config = { base: "localhost:8000", protocol: "http" };


type ApiRequest = {
  method: string;
  path: string;
  data?: unknown;
};

type ApiHeaders = Record<string, string>;

type ApiOpts = {
  method: string;
  headers: ApiHeaders;
  body?: unknown;
  credentials: string;
};

export class APIError extends Error {
  public apiErrors: Record<string, unknown>;
  constructor(object: Record<string, unknown>) {
    super("APIError");
    this.apiErrors = object;
  }
  toString() {
    return JSON.stringify(this.apiErrors);
  }
}

async function send({ method, path, data }: ApiRequest): Promise<any> {
  const { base, protocol } = config;
  const fetch = window.fetch;
  const opts: ApiOpts = {
    method,
    headers: {
      "Content-Type": "application/json",
    },
    credentials: "include",
  };

  opts.body = JSON.stringify(data);

  const url = `${protocol}://${base}/${path}`;
  console.log(opts, url);
  let r: Response | undefined;
  try {
    r = await fetch(url, opts as RequestInit);
  }
  catch (e) {
    console.log(e);
    if(e instanceof TypeError){
      console.log("Network error", e.message);
      throw new Error("Network error");
    } else {
      throw e;
    }
  }
  if (r instanceof Response) {
    if (!r.ok) {
      const errors = await r.json();
      throw new APIError(errors);
    } else {
      return await r.json();
    }
  }
}
export function get(path: string): Promise<any> {
  return send({ method: "GET", path });
}

export function del(path: string): Promise<any> {
  return send({ method: "DELETE", path });
}

export function post(path: string, data: unknown): Promise<any> {
  return send({ method: "POST", path, data });
}

export function put(path: string, data: unknown): Promise<any> {
  return send({ method: "PUT", path, data });
}

export function patch(path: string, data: unknown): Promise<any> {
  return send({ method: "PATCH", path, data });
}
